@@ -110,8 +110,15 @@ class BaseAdaptorField(object):
         return self.empty_value()
 
     def empty_value(self):
-        return ugettext(getattr(settings, 'INPLACEEDIT_EDIT_EMPTY_VALUE',
-                                          'Dobleclick to edit'))
+        '''
+        Get the text to display when the field is empty.
+        '''
+        edit_empty_value = self.config.get('edit_empty_value', False)
+        if edit_empty_value:
+            return edit_empty_value
+        else:
+            return ugettext(getattr(settings, 'INPLACEEDIT_EDIT_EMPTY_VALUE',
+                                    'Dobleclick to edit'))
 
     def render_field(self, template_name="inplaceeditform/render_field.html", extra_context=None):
         extra_context = extra_context or {}
@@ -159,12 +166,12 @@ class BaseAdaptorField(object):
         return self.config.get('auto_width', False)
 
     def treatment_height(self, height, width=None):
-        if isinstance(height, basestring) and not height.endswith('px'):
+        if isinstance(height, basestring) and not height.endswith('px') or not isinstance(height, basestring):
             height = "%spx" % height
         return height
 
     def treatment_width(self, width, height=None):
-        if isinstance(width, basestring) and not width.endswith('px'):
+        if isinstance(width, basestring) and not width.endswith('px') or not isinstance(width, basestring):
             width = "%spx" % width
         return width
 
